// Copyright 1999 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.

#import "OHHTMLDisplayProcessor-WebObjects.h"

#import <OmniBase/rcsid.h>
#import <OmniHTML/OHImageCell.h>
#import <OmniHTML/OHTextBuilder.h>
#import <OWF/OWF.h>
#import <AppKit/NSImage.h>

#import "WODProcessor.h"

RCS_ID("$Header: /Network/Source/CVS/OmniGroup/OmniComponents/Other/WebObjects/OHHTMLDisplayProcessor-WebObjects.m,v 1.3 1999/07/28 19:10:20 kc Exp $")

@implementation OHHTMLDisplayProcessor (WebObjects)

static unsigned int nameAttributeIndex;
static NSImage *beginImage, *endImage;

// Called when this bundle is loaded, this registers to get notified when we run into begin and end <webobject> tags. Note how we save the index for the "name" attribute on webobjects tags for use later. It also loads the begin and end images that we're going to insert into the displayed page.
+ (void)didLoad;
{
    OWSGMLDTD *dtd;
    OWSGMLTagType *webobjectTagType;
    OWSGMLMethods *methods;
    NSBundle *bundle;
    
    dtd = [self dtd];

    // Get the webobject tag type and name attribute - this implicitly adds these elements to our DTD (data type dictionary), which automatically updates the HTML parser to recognize these elements.
    webobjectTagType = [dtd tagTypeNamed:@"webobject"];
    nameAttributeIndex = [webobjectTagType addAttributeNamed:@"name"];

    // The OWSGMLMethods object here is a way to register to get called back to handle a particular begin or end tag.
    methods = [self sgmlMethods];
    [methods registerMethod:@"WebObject" forTagName:@"webobject"];
    [methods registerMethod:@"EndWebObject" forEndTagName:@"webobject"];

    // Load our images
    bundle = [NSBundle bundleForClass:[WODProcessor class]];
    beginImage = [[NSImage alloc] initWithContentsOfFile:[bundle pathForResource:@"begin" ofType:@"tiff"]];
    endImage = [[NSImage alloc] initWithContentsOfFile:[bundle pathForResource:@"end" ofType:@"tiff"]];
}

// When we get a begin webobject tag, we write an image cell into our displayed page with the begin image loaded earlier, and then write the name of the webobjects tag as a string into the page.
- (void)processWebObjectTag:(OWSGMLTag *)tag;
{
    NSString *name;
    OHImageCell *imageCell;

    // Get the name attribute, or use "?" if it is missing
    if (!(name = sgmlTagValueForAttributeAtIndex(tag, nameAttributeIndex)))
        name = @"?";

    // Stick an image into the displayed page at the current point
    imageCell = [[OHImageCell alloc] init];
    [imageCell setImage:beginImage];
    [textBuilder writeNonWhitespaceCellObject:imageCell];
    [imageCell release];

    // Insert the name text into the displayed page at the current point
    [textBuilder writeProcessedString:name];
}

// When we get an end webobject tag, we write an image cell into our displayed page with the end image loaded earlier.
- (void)processEndWebObjectTag:(OWSGMLTag *)tag;
{
    OHImageCell *imageCell;

    // Stick an image into the displayed page at the current point
    imageCell = [[OHImageCell alloc] init];
    [imageCell setImage:endImage];
    [textBuilder writeNonWhitespaceCellObject:imageCell];
    [imageCell release];
}

@end
